@@ -1,4 +1,6 @@
-/* eslint-disable radix, regexp/no-empty-capturing-group, regexp/no-lazy-ends, regexp/no-useless-quantifier -- required for testing */
+'use strict';
+/* eslint-disable prefer-regex-literals, radix -- required for testing */
+/* eslint-disable regexp/no-empty-capturing-group, regexp/no-lazy-ends, regexp/no-useless-quantifier -- required for testing */
 var GLOBAL = typeof global != 'undefined' ? global : Function('return this')();
 var WHITESPACES = '\u0009\u000A\u000B\u000C\u000D\u0020\u00A0\u1680\u2000\u2001\u2002' +
   '\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028\u2029\uFEFF';
@@ -8,6 +10,7 @@ var NOT_WHITESPACES = '\u200B\u0085\u180E';
 var USERAGENT = GLOBAL.navigator && GLOBAL.navigator.userAgent || '';
 
 var process = GLOBAL.process;
+var Bun = GLOBAL.Bun;
 var Deno = GLOBAL.Deno;
 var versions = process && process.versions || Deno && Deno.version;
 var v8 = versions && versions.v8;
@@ -32,7 +35,7 @@ if (!V8_VERSION && USERAGENT) {
 }
 
 var IS_BROWSER = typeof window == 'object' && typeof Deno != 'object';
-
+var IS_BUN = typeof Bun == 'function' && Bun && typeof Bun.version == 'string';
 var IS_DENO = typeof Deno == 'object' && Deno && typeof Deno.version == 'object';
 
 // var IS_NODE = Object.prototype.toString.call(process) == '[object process]';
@@ -42,14 +45,14 @@ var WEBKIT_STRING_PAD_BUG = /Version\/10(?:\.\d+){1,2}(?: [\w./]+)?(?: Mobile\/\
 var DESCRIPTORS_SUPPORT = function () {
   return Object.defineProperty({}, 'a', {
     get: function () { return 7; }
-  }).a == 7;
+  }).a === 7;
 };
 
 var V8_PROTOTYPE_DEFINE_BUG = function () {
   return Object.defineProperty(function () { /* empty */ }, 'prototype', {
     value: 42,
     writable: false
-  }).prototype == 42;
+  }).prototype === 42;
 };
 
 var PROMISES_SUPPORT = function () {
@@ -81,7 +84,7 @@ var PROMISE_STATICS_ITERATION = function () {
 };
 
 var SYMBOLS_SUPPORT = function () {
-  return Object.getOwnPropertySymbols && String(Symbol()) && !(V8_VERSION && V8_VERSION < 41);
+  return Object.getOwnPropertySymbols && String(Symbol('symbol detection')) && !(V8_VERSION && V8_VERSION < 41);
 };
 
 var SYMBOL_REGISTRY = [SYMBOLS_SUPPORT, function () {
@@ -134,7 +137,7 @@ var SAFE_ITERATION_CLOSING_SUPPORT = function () {
     iteratorWithReturn[Symbol.iterator] = function () {
       return this;
     };
-    Array.from(iteratorWithReturn, function () { throw Error('close'); });
+    Array.from(iteratorWithReturn, function () { throw new Error('close'); });
   } catch (error) {
     return SAFE_CLOSING;
   }
@@ -182,8 +185,8 @@ var TYPED_ARRAY_CONSTRUCTORS_NOT_REQUIRES_WRAPPERS = function () {
     return this;
   };
 
-  return new Int8Array(iterable)[0] == 1
-    && new Int8Array(new ArrayBuffer(2), 1, undefined).length == 1;
+  return new Int8Array(iterable)[0] === 1
+    && new Int8Array(new ArrayBuffer(2), 1, undefined).length === 1;
 };
 
 function NCG_SUPPORT() {
@@ -209,7 +212,7 @@ function createIsRegExpLogicTest(name) {
 function createStringHTMLMethodTest(METHOD_NAME) {
   return function () {
     var test = ''[METHOD_NAME]('"');
-    return test == test.toLowerCase() && test.split('"').length <= 3;
+    return test === test.toLowerCase() && test.split('"').length <= 3;
   };
 }
 
@@ -221,29 +224,77 @@ function createStringTrimMethodTest(METHOD_NAME) {
   };
 }
 
+function createSetLike(size) {
+  return {
+    size: size,
+    has: function () {
+      return false;
+    },
+    keys: function () {
+      return {
+        next: function () {
+          return { done: true };
+        }
+      };
+    }
+  };
+}
+
+function createSetMethodTest(METHOD_NAME) {
+  return function () {
+    try {
+      new Set()[METHOD_NAME](createSetLike(0));
+      try {
+        // late spec change, early WebKit ~ Safari 17.0 beta implementation does not pass it
+        // https://github.com/tc39/proposal-set-methods/pull/88
+        new Set()[METHOD_NAME](createSetLike(-1));
+        return false;
+      } catch (error2) {
+        return true;
+      }
+    } catch (error) {
+      return false;
+    }
+  };
+}
+
+function NATIVE_RAW_JSON() {
+  var unsafeInt = '9007199254740993';
+  var raw = JSON.rawJSON(unsafeInt);
+  return JSON.isRawJSON(raw) && JSON.stringify(raw) === unsafeInt;
+}
+
 function IMMEDIATE() {
-  return setImmediate && clearImmediate;
+  return setImmediate && clearImmediate && !(IS_BUN && (function () {
+    var version = global.Bun.version.split('.');
+    return version.length < 3 || version[0] === '0' && (version[1] < 3 || version[1] === '3' && version[2] === '0');
+  })());
 }
 
 function TIMERS() {
-  return !/MSIE .\./.test(USERAGENT);
+  return !(/MSIE .\./.test(USERAGENT) || IS_BUN && (function () {
+    var version = global.Bun.version.split('.');
+    return version.length < 3 || version[0] === '0' && (version[1] < 3 || version[1] === '3' && version[2] === '0');
+  })());
 }
 
 GLOBAL.tests = {
   // TODO: Remove this module from `core-js@4` since it's split to modules listed below
   'es.symbol': [SYMBOLS_SUPPORT, function () {
+    var symbol = Symbol('stringify detection');
     return Object.getOwnPropertySymbols('qwe')
       && Symbol['for']
       && Symbol.keyFor
-      && JSON.stringify([Symbol()]) == '[null]'
-      && JSON.stringify({ a: Symbol() }) == '{}'
-      && JSON.stringify(Object(Symbol())) == '{}'
+      && JSON.stringify([symbol]) === '[null]'
+      && JSON.stringify({ a: symbol }) === '{}'
+      && JSON.stringify(Object(symbol)) === '{}'
       && Symbol.prototype[Symbol.toPrimitive]
       && Symbol.prototype[Symbol.toStringTag];
   }],
   'es.symbol.constructor': SYMBOLS_SUPPORT,
   'es.symbol.description': function () {
-    return Symbol('foo').description == 'foo' && Symbol().description === undefined;
+    // eslint-disable-next-line symbol-description -- required for testing
+    return Symbol('description detection').description === 'description detection' && Symbol().description === undefined;
   },
   'es.symbol.async-iterator': function () {
     return Symbol.asyncIterator;
@@ -520,6 +571,15 @@ GLOBAL.tests = {
     };
     return array.splice().foo === 1;
   },
+  'es.array.to-reversed': function () {
+    return [].toReversed;
+  },
+  'es.array.to-sorted': function () {
+    return [].toSorted;
+  },
+  'es.array.to-spliced': function () {
+    return [].toSpliced;
+  },
   'es.array.unscopables.flat': function () {
     return Array.prototype[Symbol.unscopables].flat;
   },
@@ -534,6 +594,9 @@ GLOBAL.tests = {
       return error instanceof TypeError;
     }
   },
+  'es.array.with': function () {
+    return []['with'];
+  },
   'es.array-buffer.constructor': [ARRAY_BUFFER_SUPPORT, function () {
     try {
       return !ArrayBuffer(1);
@@ -544,7 +607,7 @@ GLOBAL.tests = {
     new ArrayBuffer();
     new ArrayBuffer(1.5);
     new ArrayBuffer(NaN);
-    return ArrayBuffer.length == 1 && ArrayBuffer.name == 'ArrayBuffer';
+    return ArrayBuffer.length === 1 && ArrayBuffer.name === 'ArrayBuffer';
   }],
   'es.array-buffer.is-view': [ARRAY_BUFFER_VIEWS_SUPPORT, function () {
     return ArrayBuffer.isView;
@@ -570,7 +633,7 @@ GLOBAL.tests = {
     try {
       new Date(NaN).toISOString();
     } catch (error) {
-      return new Date(-5e13 - 1).toISOString() == '0385-07-25T07:06:39.999Z';
+      return new Date(-5e13 - 1).toISOString() === '0385-07-25T07:06:39.999Z';
     }
   },
   'es.date.to-json': function () {
@@ -582,7 +645,7 @@ GLOBAL.tests = {
   }],
   // TODO: Remove from `core-js@4`
   'es.date.to-string': function () {
-    return new Date(NaN).toString() == 'Invalid Date';
+    return new Date(NaN).toString() === 'Invalid Date';
   },
   'es.escape': function () {
     return escape;
@@ -602,9 +665,10 @@ GLOBAL.tests = {
     return globalThis;
   },
   'es.json.stringify': [SYMBOLS_SUPPORT, function () {
-    return JSON.stringify([Symbol()]) == '[null]'
-      && JSON.stringify({ a: Symbol() }) == '{}'
-      && JSON.stringify(Object(Symbol())) == '{}'
+    var symbol = Symbol('stringify detection');
+    return JSON.stringify([symbol]) === '[null]'
+      && JSON.stringify({ a: symbol }) === '{}'
+      && JSON.stringify(Object(symbol)) === '{}'
       && JSON.stringify('\uDF06\uD834') === '"\\udf06\\ud834"'
       && JSON.stringify('\uDEAD') === '"\\udead"';
   }],
@@ -625,16 +689,16 @@ GLOBAL.tests = {
     var map = new Map(iterable);
     return map.forEach
       && map[Symbol.iterator]().next()
-      && map.get(1) == 2
-      && map.set(-0, 3) == map
+      && map.get(1) === 2
+      && map.set(-0, 3) === map
       && map.has(0)
       && map[Symbol.toStringTag];
   }],
   'es.math.acosh': function () {
     // V8 bug: https://code.google.com/p/v8/issues/detail?id=3509
-    return Math.floor(Math.acosh(Number.MAX_VALUE)) == 710
+    return Math.floor(Math.acosh(Number.MAX_VALUE)) === 710
       // Tor Browser bug: Math.acosh(Infinity) -> NaN
-      && Math.acosh(Infinity) == Infinity;
+      && Math.acosh(Infinity) === Infinity;
   },
   'es.math.asinh': function () {
     return 1 / Math.asinh(0) > 0;
@@ -653,9 +717,10 @@ GLOBAL.tests = {
   },
   'es.math.expm1': function () {
     // Old FF bug
+    // eslint-disable-next-line no-loss-of-precision -- required for old engines
     return Math.expm1(10) <= 22025.465794806719 && Math.expm1(10) >= 22025.4657948067165168
       // Tor Browser bug
-      && Math.expm1(-2e-17) == -2e-17;
+      && Math.expm1(-2e-17) === -2e-17;
   },
   'es.math.fround': function () {
     return Math.fround;
@@ -664,7 +729,7 @@ GLOBAL.tests = {
     return Math.hypot && Math.hypot(Infinity, NaN) === Infinity;
   },
   'es.math.imul': function () {
-    return Math.imul(0xFFFFFFFF, 5) == -5 && Math.imul.length == 2;
+    return Math.imul(0xFFFFFFFF, 5) === -5 && Math.imul.length === 2;
   },
   'es.math.log10': function () {
     return Math.log10;
@@ -679,7 +744,7 @@ GLOBAL.tests = {
     return Math.sign;
   },
   'es.math.sinh': function () {
-    return Math.sinh(-2e-17) == -2e-17;
+    return Math.sinh(-2e-17) === -2e-17;
   },
   'es.math.tanh': function () {
     return Math.tanh;
@@ -775,11 +840,11 @@ GLOBAL.tests = {
     }), { b: 2 })).b !== 1) return false;
     var A = {};
     var B = {};
-    var symbol = Symbol();
+    var symbol = Symbol('assign detection');
     var alphabet = 'abcdefghijklmnopqrst';
     A[symbol] = 7;
     alphabet.split('').forEach(function (chr) { B[chr] = chr; });
-    return Object.assign({}, A)[symbol] == 7 && Object.keys(Object.assign({}, B)).join('') == alphabet;
+    return Object.assign({}, A)[symbol] === 7 && Object.keys(Object.assign({}, B)).join('') === alphabet;
   },
   // TODO: Remove from `core-js@4`
   'es.object.create': function () {
@@ -876,12 +941,12 @@ GLOBAL.tests = {
   'es.promise.all': [PROMISES_SUPPORT, SAFE_ITERATION_CLOSING_SUPPORT, PROMISE_STATICS_ITERATION, function () {
     return Promise.all;
   }],
-  'es.promise.all-settled': function () {
+  'es.promise.all-settled': [PROMISES_SUPPORT, SAFE_ITERATION_CLOSING_SUPPORT, PROMISE_STATICS_ITERATION, function () {
     return Promise.allSettled;
-  },
-  'es.promise.any': function () {
+  }],
+  'es.promise.any': [PROMISES_SUPPORT, SAFE_ITERATION_CLOSING_SUPPORT, PROMISE_STATICS_ITERATION, function () {
     return Promise.any;
-  },
+  }],
   'es.promise.catch': PROMISES_SUPPORT,
   'es.promise.finally': [PROMISES_SUPPORT, function () {
     // eslint-disable-next-line unicorn/no-thenable -- required for testing
@@ -955,7 +1020,7 @@ GLOBAL.tests = {
     return new RegExp(re1) !== re1
       && RegExp(re1) === re1
       && RegExp(re2) !== re2
-      && RegExp(re1, 'i') == '/a/i'
+      && String(RegExp(re1, 'i')) === '/a/i'
       && new RegExp('a', 'y') // just check that it doesn't throw
       && RegExp('.', 's').exec('\n')
       && RegExp[Symbol.species];
@@ -1048,7 +1113,7 @@ GLOBAL.tests = {
     return set.forEach
       && set[Symbol.iterator]().next()
       && set.has(1)
-      && set.add(-0) == set
+      && set.add(-0) === set
       && set.has(0)
       && set[Symbol.toStringTag];
   }],
@@ -1063,6 +1128,9 @@ GLOBAL.tests = {
     return String.fromCodePoint;
   },
   'es.string.includes': createIsRegExpLogicTest('includes'),
+  'es.string.is-well-formed': function () {
+    return String.prototype.isWellFormed;
+  },
   'es.string.iterator': [SYMBOLS_SUPPORT, function () {
     return ''[Symbol.iterator];
   }],
@@ -1072,14 +1140,18 @@ GLOBAL.tests = {
 
     var execCalled = false;
     var re = /a/;
-    re.exec = function () { execCalled = true; return null; };
+    re.exec = function () {
+      execCalled = true;
+      return null;
+    };
     re[Symbol.match]('');
 
     // eslint-disable-next-line regexp/prefer-regexp-exec -- required for testing
-    return ''.match(O) == 7 && execCalled;
+    return ''.match(O) === 7 && execCalled;
   },
   'es.string.match-all': function () {
     try {
+      // eslint-disable-next-line regexp/no-missing-g-flag -- required for testing
       'a'.matchAll(/./);
     } catch (error) {
       return 'a'.matchAll(/./g);
@@ -1103,7 +1175,10 @@ GLOBAL.tests = {
 
     var execCalled = false;
     var re = /a/;
-    re.exec = function () { execCalled = true; return null; };
+    re.exec = function () {
+      execCalled = true;
+      return null;
+    };
     re[Symbol.replace]('');
 
     var re2 = /./;
@@ -1113,7 +1188,7 @@ GLOBAL.tests = {
       return result;
     };
 
-    return ''.replace(O) == 7
+    return ''.replace(O) === 7
       && execCalled
       // eslint-disable-next-line regexp/no-useless-dollar-replacements -- false positive
       && ''.replace(re2, '$<a>') === '7'
@@ -1130,10 +1205,13 @@ GLOBAL.tests = {
 
     var execCalled = false;
     var re = /a/;
-    re.exec = function () { execCalled = true; return null; };
+    re.exec = function () {
+      execCalled = true;
+      return null;
+    };
     re[Symbol.search]('');
 
-    return ''.search(O) == 7 && execCalled;
+    return ''.search(O) === 7 && execCalled;
   },
   'es.string.split': function () {
     var O = {};
@@ -1141,7 +1219,10 @@ GLOBAL.tests = {
 
     var execCalled = false;
     var re = /a/;
-    re.exec = function () { execCalled = true; return null; };
+    re.exec = function () {
+      execCalled = true;
+      return null;
+    };
     re.constructor = {};
     re.constructor[Symbol.species] = function () { return re; };
     re[Symbol.split]('');
@@ -1152,13 +1233,17 @@ GLOBAL.tests = {
     re2.exec = function () { return originalExec.apply(this, arguments); };
     var result = 'ab'.split(re2);
 
-    return ''.split(O) == 7 && execCalled && result.length === 2 && result[0] === 'a' && result[1] === 'b';
+    return ''.split(O) === 7 && execCalled && result.length === 2 && result[0] === 'a' && result[1] === 'b';
   },
   'es.string.starts-with': createIsRegExpLogicTest('startsWith'),
   'es.string.substr': function () {
-    // eslint-disable-next-line unicorn/prefer-string-slice -- required for testing
     return 'ab'.substr(-1) === 'b';
   },
+  'es.string.to-well-formed': function () {
+    // Safari ToString conversion bug
+    // https://bugs.webkit.org/show_bug.cgi?id=251757
+    return String.prototype.toWellFormed.call(1) === '1';
+  },
   'es.string.trim': createStringTrimMethodTest('trim'),
   'es.string.trim-end': [createStringTrimMethodTest('trimEnd'), function () {
     return String.prototype.trimRight === String.prototype.trimEnd;
@@ -1346,17 +1431,30 @@ GLOBAL.tests = {
     try {
       Int8Array.prototype.toLocaleString.call([1, 2]);
     } catch (error) {
-      return [1, 2].toLocaleString() == new Int8Array([1, 2]).toLocaleString();
+      return [1, 2].toLocaleString() === new Int8Array([1, 2]).toLocaleString();
     }
   }],
   'es.typed-array.to-string': [ARRAY_BUFFER_VIEWS_SUPPORT, function () {
-    return Int8Array.prototype.toString == Array.prototype.toString;
+    return Int8Array.prototype.toString === Array.prototype.toString;
   }],
+  'es.typed-array.to-reversed': function () {
+    return Int8Array.prototype.toReversed;
+  },
+  'es.typed-array.to-sorted': function () {
+    return Int8Array.prototype.toSorted;
+  },
+  'es.typed-array.with': function () {
+    try {
+      new Int8Array(1)['with'](2, { valueOf: function () { throw 8; } });
+    } catch (error) {
+      return error === 8;
+    }
+  },
   'es.unescape': function () {
     return unescape;
   },
   'es.weak-map.constructor': [SAFE_ITERATION_CLOSING_SUPPORT, function () {
-    var key = Object.freeze({});
+    var key = Object.freeze([]);
     var called = 0;
     var iterable = {
       next: function () {
@@ -1368,10 +1466,13 @@ GLOBAL.tests = {
     };
 
     var map = new WeakMap(iterable);
-    return map.get(key) == 1
-      && map.get(null) == undefined
-      && map.set({}, 2) == map
-      && map[Symbol.toStringTag];
+    // MS IE bug
+    return map.get(key) === 1
+      && map.get(null) === undefined
+      && map.set({}, 2) === map
+      && map[Symbol.toStringTag]
+      // MS Edge bug
+      && Object.isFrozen(key);
   }],
   'es.weak-set.constructor': [SAFE_ITERATION_CLOSING_SUPPORT, function () {
     var key = {};
@@ -1388,52 +1489,42 @@ GLOBAL.tests = {
     var set = new WeakSet(iterable);
     return set.has(key)
       && !set.has(null)
-      && set.add({}) == set
+      && set.add({}) === set
       && set[Symbol.toStringTag];
   }],
+  'esnext.suppressed-error.constructor': function () {
+    return typeof SuppressedError == 'function';
+  },
   'esnext.array.from-async': function () {
     return Array.fromAsync;
   },
   'esnext.array.filter-reject': function () {
     return [].filterReject;
   },
-  'esnext.array.group': function () {
-    try {
-      // https://bugs.webkit.org/show_bug.cgi?id=236541
-      Array.prototype.group.call(null, function () { /* empty */ });
-      return false;
-    } catch (error) { /* empty */ }
-    return Array.prototype.group;
-  },
-  'esnext.array.group-to-map': function () {
-    try {
-      // https://bugs.webkit.org/show_bug.cgi?id=236541
-      Array.prototype.groupToMap.call(null, function () { /* empty */ });
-      return false;
-    } catch (error) { /* empty */ }
-    return Array.prototype.groupToMap;
-  },
   'esnext.array.is-template-object': function () {
     return Array.isTemplateObject;
   },
-  'esnext.array.to-reversed': function () {
-    return [].toReversed;
-  },
-  'esnext.array.to-sorted': function () {
-    return [].toSorted;
-  },
-  'esnext.array.to-spliced': function () {
-    return [].toSpliced;
-  },
   'esnext.array.unique-by': function () {
     return [].uniqueBy;
   },
-  'esnext.array.with': function () {
-    return []['with'];
+  'esnext.array-buffer.detached': function () {
+    return 'detached' in ArrayBuffer.prototype;
+  },
+  'esnext.array-buffer.transfer': function () {
+    return ArrayBuffer.prototype.transfer;
+  },
+  'esnext.array-buffer.transfer-to-fixed-length': function () {
+    return ArrayBuffer.prototype.transferToFixedLength;
+  },
+  'esnext.async-disposable-stack.constructor': function () {
+    return typeof AsyncDisposableStack == 'function';
   },
   'esnext.async-iterator.constructor': function () {
     return typeof AsyncIterator == 'function';
   },
+  'esnext.async-iterator.async-dispose': function () {
+    return AsyncIterator.prototype[Symbol.asyncDispose];
+  },
   'esnext.async-iterator.drop': function () {
     return AsyncIterator.prototype.drop;
   },
@@ -1455,9 +1546,6 @@ GLOBAL.tests = {
   'esnext.async-iterator.from': function () {
     return AsyncIterator.from;
   },
-  'esnext.async-iterator.indexed': function () {
-    return AsyncIterator.prototype.indexed;
-  },
   'esnext.async-iterator.map': function () {
     return AsyncIterator.prototype.map;
   },
@@ -1473,23 +1561,38 @@ GLOBAL.tests = {
   'esnext.async-iterator.to-array': function () {
     return AsyncIterator.prototype.toArray;
   },
-  'esnext.bigint.range': function () {
-    return BigInt.range;
-  },
   'esnext.composite-key': function () {
     return compositeKey;
   },
   'esnext.composite-symbol': function () {
     return compositeSymbol;
   },
+  'esnext.data-view.get-float16': [ARRAY_BUFFER_SUPPORT, function () {
+    return DataView.prototype.getFloat16;
+  }],
+  'esnext.data-view.get-uint8-clamped': [ARRAY_BUFFER_SUPPORT, function () {
+    return DataView.prototype.getUint8Clamped;
+  }],
+  'esnext.data-view.set-float16': [ARRAY_BUFFER_SUPPORT, function () {
+    return DataView.prototype.setFloat16;
+  }],
+  'esnext.data-view.set-uint8-clamped': [ARRAY_BUFFER_SUPPORT, function () {
+    return DataView.prototype.setUint8Clamped;
+  }],
+  'esnext.disposable-stack.constructor': function () {
+    return typeof DisposableStack == 'function';
+  },
+  'esnext.function.demethodize': function () {
+    return Function.prototype.demethodize;
+  },
   'esnext.function.is-callable': function () {
     return Function.isCallable;
   },
   'esnext.function.is-constructor': function () {
     return Function.isConstructor;
   },
-  'esnext.function.un-this': function () {
-    return Function.prototype.unThis;
+  'esnext.function.metadata': function () {
+    return Function.prototype[Symbol.metadata] === null;
   },
   'esnext.iterator.constructor': function () {
     try {
@@ -1499,6 +1602,9 @@ GLOBAL.tests = {
         && Iterator.prototype === Object.getPrototypeOf(Object.getPrototypeOf([].values()));
     }
   },
+  'esnext.iterator.dispose': function () {
+    return [].keys()[Symbol.dispose];
+  },
   'esnext.iterator.drop': function () {
     return Iterator.prototype.drop;
   },
@@ -1520,12 +1626,12 @@ GLOBAL.tests = {
   'esnext.iterator.from': function () {
     return Iterator.from;
   },
-  'esnext.iterator.indexed': function () {
-    return Iterator.prototype.indexed;
-  },
   'esnext.iterator.map': function () {
     return Iterator.prototype.map;
   },
+  'esnext.iterator.range': function () {
+    return Iterator.range;
+  },
   'esnext.iterator.reduce': function () {
     return Iterator.prototype.reduce;
   },
@@ -1541,6 +1647,16 @@ GLOBAL.tests = {
   'esnext.iterator.to-async': function () {
     return Iterator.prototype.toAsync;
   },
+  'esnext.json.is-raw-json': NATIVE_RAW_JSON,
+  'esnext.json.parse': function () {
+    var unsafeInt = '9007199254740993';
+    var source;
+    JSON.parse(unsafeInt, function (key, value, context) {
+      source = context.source;
+    });
+    return source === unsafeInt;
+  },
+  'esnext.json.raw-json': NATIVE_RAW_JSON,
   'esnext.map.delete-all': function () {
     return Map.prototype.deleteAll;
   },
@@ -1607,6 +1723,9 @@ GLOBAL.tests = {
   'esnext.math.fscale': function () {
     return Math.fscale;
   },
+  'esnext.math.f16round': function () {
+    return Math.f16round;
+  },
   'esnext.math.rad-per-deg': function () {
     return Math.RAD_PER_DEG;
   },
@@ -1622,21 +1741,14 @@ GLOBAL.tests = {
   'esnext.number.from-string': function () {
     return Number.fromString;
   },
-  'esnext.number.range': function () {
-    return Number.range;
+  'esnext.object.group-by': function () {
+    return Object.groupBy;
   },
-  // TODO: Remove this module from `core-js@4` since it's split to modules listed below
-  'esnext.observable': function () {
-    return Observable;
-  },
-  'esnext.observable.constructor': function () {
-    return Observable;
-  },
-  'esnext.observable.from': function () {
-    return Observable.from;
-  },
-  'esnext.observable.of': function () {
-    return Observable.of;
+  'esnext.promise.with-resolvers': [PROMISES_SUPPORT, function () {
+    return Promise.withResolvers;
+  }],
+  'esnext.regexp.escape': function () {
+    return RegExp.escape;
   },
   'esnext.set.add-all': function () {
     return Set.prototype.addAll;
@@ -1644,9 +1756,7 @@ GLOBAL.tests = {
   'esnext.set.delete-all': function () {
     return Set.prototype.deleteAll;
   },
-  'esnext.set.difference': function () {
-    return Set.prototype.difference;
-  },
+  'esnext.set.difference.v2': createSetMethodTest('difference'),
   'esnext.set.every': function () {
     return Set.prototype.every;
   },
@@ -1659,18 +1769,12 @@ GLOBAL.tests = {
   'esnext.set.from': function () {
     return Set.from;
   },
-  'esnext.set.intersection': function () {
-    return Set.prototype.intersection;
-  },
-  'esnext.set.is-disjoint-from': function () {
-    return Set.prototype.isDisjointFrom;
-  },
-  'esnext.set.is-subset-of': function () {
-    return Set.prototype.isSubsetOf;
-  },
-  'esnext.set.is-superset-of': function () {
-    return Set.prototype.isSupersetOf;
-  },
+  'esnext.set.intersection.v2': [createSetMethodTest('intersection'), function () {
+    return Array.from(new Set([1, 2, 3]).intersection(new Set([3, 2]))) === '3,2';
+  }],
+  'esnext.set.is-disjoint-from.v2': createSetMethodTest('isDisjointFrom'),
+  'esnext.set.is-subset-of.v2': createSetMethodTest('isSubsetOf'),
+  'esnext.set.is-superset-of.v2': createSetMethodTest('isSupersetOf'),
   'esnext.set.join': function () {
     return Set.prototype.join;
   },
@@ -1686,29 +1790,36 @@ GLOBAL.tests = {
   'esnext.set.some': function () {
     return Set.prototype.some;
   },
-  'esnext.set.symmetric-difference': function () {
-    return Set.prototype.symmetricDifference;
-  },
-  'esnext.set.union': function () {
-    return Set.prototype.union;
-  },
+  'esnext.set.symmetric-difference.v2': createSetMethodTest('symmetricDifference'),
+  'esnext.set.union.v2': createSetMethodTest('union'),
   'esnext.string.code-points': function () {
     return String.prototype.codePoints;
   },
   'esnext.string.cooked': function () {
     return String.cooked;
   },
+  'esnext.string.dedent': function () {
+    return String.dedent;
+  },
   'esnext.symbol.async-dispose': function () {
-    return Symbol.dispose;
+    var descriptor = Object.getOwnPropertyDescriptor(Symbol, 'asyncDispose');
+    return descriptor.value && !descriptor.enumerable && !descriptor.configurable && !descriptor.writable;
   },
   'esnext.symbol.dispose': function () {
-    return Symbol.dispose;
+    var descriptor = Object.getOwnPropertyDescriptor(Symbol, 'dispose');
+    return descriptor.value && !descriptor.enumerable && !descriptor.configurable && !descriptor.writable;
+  },
+  'esnext.symbol.is-registered-symbol': function () {
+    return Symbol.isRegisteredSymbol;
+  },
+  'esnext.symbol.is-well-known-symbol': function () {
+    return Symbol.isWellKnownSymbol;
   },
   'esnext.symbol.matcher': function () {
     return Symbol.matcher;
   },
-  'esnext.symbol.metadata-key': function () {
-    return Symbol.metadataKey;
+  'esnext.symbol.metadata': function () {
+    return Symbol.metadata;
   },
   'esnext.symbol.observable': function () {
     return Symbol.observable;
@@ -1716,22 +1827,9 @@ GLOBAL.tests = {
   'esnext.typed-array.filter-reject': function () {
     return Int8Array.prototype.filterReject;
   },
-  'esnext.typed-array.to-reversed': function () {
-    return Int8Array.prototype.toReversed;
-  },
-  'esnext.typed-array.to-sorted': function () {
-    return Int8Array.prototype.toSorted;
-  },
   'esnext.typed-array.unique-by': function () {
     return Int8Array.prototype.uniqueBy;
   },
-  'esnext.typed-array.with': function () {
-    try {
-      new Int8Array(1)['with'](2, { valueOf: function () { throw 8; } });
-    } catch (error) {
-      return error === 8;
-    }
-  },
   'esnext.weak-map.delete-all': function () {
     return WeakMap.prototype.deleteAll;
   },
@@ -1774,7 +1872,9 @@ GLOBAL.tests = {
       return typeof btoa == 'function';
     }
   },
-  'web.clear-immediate': IMMEDIATE,
+  'web.clear-immediate': function () {
+    return setImmediate && clearImmediate;
+  },
   'web.dom-collections.for-each': function () {
     return (!GLOBAL.NodeList || (NodeList.prototype.forEach && NodeList.prototype.forEach === [].forEach))
       && (!GLOBAL.DOMTokenList || (DOMTokenList.prototype.forEach && DOMTokenList.prototype.forEach === [].forEach));
@@ -1847,6 +1947,13 @@ GLOBAL.tests = {
   'web.queue-microtask': function () {
     return Object.getOwnPropertyDescriptor(GLOBAL, 'queueMicrotask').value;
   },
+  'web.self': function () {
+    // eslint-disable-next-line no-restricted-globals -- safe
+    if (self !== GLOBAL) return false;
+    if (!DESCRIPTORS_SUPPORT) return true;
+    var descriptor = Object.getOwnPropertyDescriptor(GLOBAL, 'self');
+    return descriptor.get && descriptor.enumerable;
+  },
   'web.set-immediate': IMMEDIATE,
   'web.set-interval': TIMERS,
   'web.set-timeout': TIMERS,
@@ -1859,7 +1966,7 @@ GLOBAL.tests = {
 
     function checkNewErrorsCloningSemantic(structuredCloneImplementation) {
       var test = structuredCloneImplementation(new AggregateError([1], 'message', { cause: 3 }));
-      return test.name == 'AggregateError' && test.errors[0] == 1 && test.message == 'message' && test.cause == 3;
+      return test.name === 'AggregateError' && test.errors[0] === 1 && test.message === 'message' && test.cause === 3;
     }
 
     return checkErrorsCloning(structuredClone, Error)
@@ -1869,8 +1976,32 @@ GLOBAL.tests = {
   // TODO: Remove this module from `core-js@4` since it's split to submodules
   'web.timers': TIMERS,
   'web.url.constructor': URL_AND_URL_SEARCH_PARAMS_SUPPORT,
+  'web.url.can-parse': [URL_AND_URL_SEARCH_PARAMS_SUPPORT, function () {
+    try {
+      URL.canParse();
+    } catch (error) {
+      return URL.canParse;
+    }
+  }],
   'web.url.to-json': [URL_AND_URL_SEARCH_PARAMS_SUPPORT, function () {
     return URL.prototype.toJSON;
   }],
-  'web.url-search-params.constructor': URL_AND_URL_SEARCH_PARAMS_SUPPORT
+  'web.url-search-params.constructor': URL_AND_URL_SEARCH_PARAMS_SUPPORT,
+  'web.url-search-params.delete': [URL_AND_URL_SEARCH_PARAMS_SUPPORT, function () {
+    var params = new URLSearchParams('a=1&a=2&b=3');
+    params['delete']('a', 1);
+    // `undefined` case is a Chromium 117 bug
+    // https://bugs.chromium.org/p/v8/issues/detail?id=14222
+    params['delete']('b', undefined);
+    return params + '' === 'a=2';
+  }],
+  'web.url-search-params.has': [URL_AND_URL_SEARCH_PARAMS_SUPPORT, function () {
+    var params = new URLSearchParams('a=1');
+    // `undefined` case is a Chromium 117 bug
+    // https://bugs.chromium.org/p/v8/issues/detail?id=14222
+    return params.has('a', 1) && !params.has('a', 2) && params.has('a', undefined);
+  }],
+  'web.url-search-params.size': [URL_AND_URL_SEARCH_PARAMS_SUPPORT, function () {
+    return 'size' in URLSearchParams.prototype;
+  }]
 };
