@@ -1,7 +1,8 @@
+'use strict';
+require('../../modules/es.array.iterator');
 require('../../modules/es.map');
 require('../../modules/es.object.to-string');
 require('../../modules/es.string.iterator');
-require('../../modules/web.dom-collections.iterator');
 var path = require('../../internals/path');
 
 module.exports = path.Map;
