@@ -1,3 +1,4 @@
+'use strict';
 require('../../modules/es.symbol');
 require('../../modules/es.object.assign');
 require('../../modules/es.object.create');
@@ -10,12 +11,14 @@ require('../../modules/es.object.get-own-property-descriptor');
 require('../../modules/es.object.get-own-property-descriptors');
 require('../../modules/es.object.get-own-property-names');
 require('../../modules/es.object.get-prototype-of');
+require('../../modules/es.object.has-own');
 require('../../modules/es.object.is');
 require('../../modules/es.object.is-extensible');
 require('../../modules/es.object.is-frozen');
 require('../../modules/es.object.is-sealed');
 require('../../modules/es.object.keys');
 require('../../modules/es.object.prevent-extensions');
+require('../../modules/es.object.proto');
 require('../../modules/es.object.seal');
 require('../../modules/es.object.set-prototype-of');
 require('../../modules/es.object.values');
