@@ -1,8 +1,13 @@
-import { DESCRIPTORS } from './constants';
+import { DESCRIPTORS } from './constants.js';
 import assign from 'core-js-pure/es/object/assign';
+import defineProperties from 'core-js-pure/es/object/define-properties';
 import isIterable from 'core-js-pure/es/is-iterable';
 import ASYNC_ITERATOR from 'core-js-pure/es/symbol/async-iterator';
-import { is, arrayFromArrayLike } from './helpers';
+import { is, arrayFromArrayLike } from './helpers.js';
+
+// for Babel template transform
+if (!Object.freeze) Object.freeze = Object;
+if (!DESCRIPTORS) Object.defineProperties = defineProperties;
 
 const { getOwnPropertyDescriptor } = Object;
 const { toString, propertyIsEnumerable } = Object.prototype;
@@ -24,11 +29,11 @@ assign(QUnit.assert, {
       actual: result,
       expected: 'The property should be enumerable',
       message: DESCRIPTORS
-        ? 'Enumerability is not applicable'
-        : message ?? `${ typeof key == 'symbol' ? 'property' : `'${ key }'` } is enumerable`,
+        ? message ?? `${ typeof key == 'symbol' ? 'property' : `'${ key }'` } is enumerable`
+        : 'Enumerability is not applicable',
     });
   },
-  epsilon(a, b, EPSILON = 1e-11, message) {
+  epsilon(a, b, EPSILON = 1e-11, message = null) {
     const result = Math.abs(a - b) <= EPSILON;
     this.pushResult({
       result,
@@ -37,8 +42,8 @@ assign(QUnit.assert, {
       message: message ?? `The value should be closer to the target by less than ${ EPSILON }`,
     });
   },
-  // TODO: Drop from `core-js@4`
-  // unavailable in `qunit@1` that's required for testing in IE8-
+  // TODO: Drop from ~ `core-js@5`
+  // unavailable in `qunit@1` that's required for testing in IE9-
   false(value, message = 'The value is `false`') {
     this.same(value, false, message);
   },
@@ -79,7 +84,7 @@ assign(QUnit.assert, {
     this.pushResult({
       result: /native code/.test(source),
       actual: source,
-      expected: 'The function should looks like a native',
+      expected: 'The function should look like a native',
       message,
     });
   },
@@ -102,8 +107,8 @@ assign(QUnit.assert, {
       actual: result,
       expected: 'The property should be non-configurable',
       message: DESCRIPTORS
-        ? 'Configurability is not applicable'
-        : message ?? `${ typeof key == 'symbol' ? 'property' : `'${ key }'` } is non-configurable`,
+        ? message ?? `${ typeof key == 'symbol' ? 'property' : `'${ key }'` } is non-configurable`
+        : 'Configurability is not applicable',
     });
   },
   nonEnumerable(O, key, message) {
@@ -113,8 +118,8 @@ assign(QUnit.assert, {
       actual: result,
       expected: 'The property should be non-enumerable',
       message: DESCRIPTORS
-        ? 'Enumerability is not applicable'
-        : message ?? `${ typeof key == 'symbol' ? 'property' : `'${ key }'` } is non-enumerable`,
+        ? message ?? `${ typeof key == 'symbol' ? 'property' : `'${ key }'` } is non-enumerable`
+        : 'Enumerability is not applicable',
     });
   },
   nonWritable(O, key, message) {
@@ -124,8 +129,8 @@ assign(QUnit.assert, {
       actual: result,
       expected: 'The property should be non-writable',
       message: DESCRIPTORS
-        ? 'Writability is not applicable'
-        : message ?? `${ typeof key == 'symbol' ? 'property' : `'${ key }'` } is non-writable`,
+        ? message ?? `${ typeof key == 'symbol' ? 'property' : `'${ key }'` } is non-writable`
+        : 'Writability is not applicable',
     });
   },
   notSame(actual, expected, message) {
@@ -163,8 +168,8 @@ assign(QUnit.assert, {
       message,
     });
   },
-  // TODO: Drop from `core-js@4`
-  // unavailable in `qunit@1` that's required for testing in IE8-
+  // TODO: Drop from ~ `core-js@5`
+  // unavailable in `qunit@1` that's required for testing in IE9-
   true(value, message = 'The value is `true`') {
     this.same(value, true, message);
   },
