@@ -1,4 +1,4 @@
-import { GLOBAL, WHITESPACES } from '../helpers/constants';
+import { GLOBAL, WHITESPACES } from '../helpers/constants.js';
 
 QUnit.test('Number.parseFloat', assert => {
   const { parseFloat } = Number;
@@ -20,7 +20,8 @@ QUnit.test('Number.parseFloat', assert => {
   assert.same(parseFloat(undefined), NaN);
 
   if (typeof Symbol == 'function' && !Symbol.sham) {
-    assert.throws(() => parseFloat(Symbol()), 'throws on symbol argument');
-    assert.throws(() => parseFloat(Object(Symbol())), 'throws on boxed symbol argument');
+    const symbol = Symbol('Number.parseFloat test');
+    assert.throws(() => parseFloat(symbol), 'throws on symbol argument');
+    assert.throws(() => parseFloat(Object(symbol)), 'throws on boxed symbol argument');
   }
 });
