@@ -1,4 +1,4 @@
-import { GLOBAL, NATIVE } from '../helpers/constants';
+import { GLOBAL, NATIVE } from '../helpers/constants.js';
 
 QUnit.test('Object.seal', assert => {
   const { seal, isSealed, keys, getOwnPropertyNames, getOwnPropertySymbols } = Object;
