@@ -1,8 +1,8 @@
 
 QUnit.test('RegExp#test delegates to exec', assert => {
-  const exec = function () {
+  const exec = function (...args) {
     execCalled = true;
-    return /./.exec.apply(this, arguments);
+    return /./.exec.apply(this, args);
   };
 
   let execCalled = false;
