@@ -9,7 +9,8 @@ QUnit.test('String#anchor', assert => {
   assert.same('a'.anchor('"'), '<a name="&quot;">a</a>', 'escape quotes');
 
   if (typeof Symbol == 'function' && !Symbol.sham) {
-    assert.throws(() => anchor.call(Symbol(), 'b'), 'throws on symbol context');
-    assert.throws(() => anchor.call('a', Symbol()), 'throws on symbol argument');
+    const symbol = Symbol('anchor test');
+    assert.throws(() => anchor.call(symbol, 'b'), 'throws on symbol context');
+    assert.throws(() => anchor.call('a', symbol), 'throws on symbol argument');
   }
 });
