@@ -1,4 +1,4 @@
-import { STRICT } from '../helpers/constants';
+import { STRICT } from '../helpers/constants.js';
 
 QUnit.test('String#at', assert => {
   const { at } = String.prototype;
@@ -25,7 +25,7 @@ QUnit.test('String#at', assert => {
   // assert.same('\uD842', '𠮷'.at());
   assert.same('1', at.call({ toString() { return '123'; } }, 0));
 
-  assert.throws(() => at.call(Symbol(), 0), 'throws on symbol context');
+  assert.throws(() => at.call(Symbol('at-alternative test'), 0), 'throws on symbol context');
 
   if (STRICT) {
     assert.throws(() => at.call(null, 0), TypeError);
