@@ -1,4 +1,4 @@
-import { GLOBAL } from '../helpers/constants';
+import { GLOBAL } from '../helpers/constants.js';
 
 const Symbol = GLOBAL.Symbol || {};
 
@@ -44,5 +44,6 @@ QUnit.test('String#@@iterator', assert => {
     done: true,
   });
 
-  assert.throws(() => ''[Symbol.iterator].call(Symbol()), 'throws on symbol context');
+  // early FF case with native method, but polyfilled `Symbol`
+  // assert.throws(() => ''[Symbol.iterator].call(Symbol()), 'throws on symbol context');
 });
