@@ -1,4 +1,4 @@
-import { STRICT } from '../helpers/constants';
+import { STRICT } from '../helpers/constants.js';
 
 QUnit.test('String#padStart', assert => {
   const { padStart } = String.prototype;
@@ -15,8 +15,9 @@ QUnit.test('String#padStart', assert => {
   assert.same('foo'.padStart(1), 'foo');
   assert.same('foo'.padStart(5, ''), 'foo');
 
-  assert.throws(() => padStart.call(Symbol(), 10, 'a'), 'throws on symbol context');
-  assert.throws(() => padStart.call('a', 10, Symbol()), 'throws on symbol argument');
+  const symbol = Symbol('padStart test');
+  assert.throws(() => padStart.call(symbol, 10, 'a'), 'throws on symbol context');
+  assert.throws(() => padStart.call('a', 10, symbol), 'throws on symbol argument');
 
   if (STRICT) {
     assert.throws(() => padStart.call(null, 0), TypeError);
