@@ -1,4 +1,4 @@
-import { STRICT } from '../helpers/constants';
+import { STRICT } from '../helpers/constants.js';
 
 QUnit.test('String#repeat', assert => {
   const { repeat } = String.prototype;
@@ -13,7 +13,7 @@ QUnit.test('String#repeat', assert => {
   assert.throws(() => 'qwe'.repeat(Infinity), RangeError);
 
   if (typeof Symbol == 'function' && !Symbol.sham) {
-    assert.throws(() => repeat.call(Symbol()), 'throws on symbol context');
+    assert.throws(() => repeat.call(Symbol('repeat test')), 'throws on symbol context');
   }
 
   if (STRICT) {
