@@ -1,4 +1,5 @@
-import { DESCRIPTORS } from '../helpers/constants';
+/* eslint-disable symbol-description -- required for testing */
+import { DESCRIPTORS } from '../helpers/constants.js';
 
 QUnit.test('Symbol#description', assert => {
   assert.same(Symbol('foo').description, 'foo');
