@@ -1,4 +1,4 @@
-import { DESCRIPTORS, TYPED_ARRAYS } from '../helpers/constants';
+import { DESCRIPTORS, TYPED_ARRAYS } from '../helpers/constants.js';
 
 if (DESCRIPTORS) QUnit.test('%TypedArrayPrototype%.includes', assert => {
   // we can't implement %TypedArrayPrototype% in all engines, so run all tests for each typed array constructor
