@@ -1,5 +1,5 @@
 // TODO: Remove from `core-js@4`
-import { STRICT } from '../helpers/constants';
+import { STRICT } from '../helpers/constants.js';
 
 QUnit.test('Array#filterOut', assert => {
   const { filterOut } = Array.prototype;
