@@ -1,3 +1,5 @@
+import { nativeSubclass } from '../helpers/helpers.js';
+
 const { getPrototypeOf } = Object;
 
 QUnit.test('AsyncIterator', assert => {
@@ -22,7 +24,12 @@ QUnit.test('AsyncIterator', assert => {
   assert.true(AsyncIterator.from([1, 2, 3]) instanceof AsyncIterator, 'Async From Proxy');
   assert.true(AsyncIterator.from([1, 2, 3]).drop(1) instanceof AsyncIterator, 'Async Drop Proxy');
 
-  assert.true(new AsyncIterator() instanceof AsyncIterator, 'constructor');
+  if (nativeSubclass) {
+    const Sub = nativeSubclass(AsyncIterator);
+    assert.true(new Sub() instanceof AsyncIterator, 'abstract constructor');
+  }
+
+  assert.throws(() => new AsyncIterator(), 'direct constructor throws');
   assert.throws(() => AsyncIterator(), 'throws w/o `new`');
 });
 
