@@ -1,8 +1,7 @@
-import { createIterator } from '../helpers/helpers';
+import { STRICT } from '../helpers/constants.js';
+import { createIterator } from '../helpers/helpers.js';
 
 QUnit.test('AsyncIterator#drop', assert => {
-  assert.expect(15);
-  const async = assert.async();
   const { drop } = AsyncIterator.prototype;
 
   assert.isFunction(drop);
@@ -11,7 +10,15 @@ QUnit.test('AsyncIterator#drop', assert => {
   assert.looksNative(drop);
   assert.nonEnumerable(AsyncIterator.prototype, 'drop');
 
-  drop.call(createIterator([1, 2, 3]), 1).toArray().then(it => {
+  if (STRICT) {
+    assert.throws(() => drop.call(undefined, 1), TypeError);
+    assert.throws(() => drop.call(null, 1), TypeError);
+  }
+
+  assert.throws(() => drop.call(createIterator([1, 2, 3]), -1), RangeError, 'negative');
+  assert.throws(() => drop.call(createIterator([1, 2, 3]), NaN), RangeError, 'NaN');
+
+  return drop.call(createIterator([1, 2, 3]), 1).toArray().then(it => {
     assert.arrayEqual(it, [2, 3], 'basic functionality');
     return drop.call(createIterator([1, 2, 3]), 1.5).toArray();
   }).then(it => {
@@ -22,13 +29,5 @@ QUnit.test('AsyncIterator#drop', assert => {
     return drop.call(createIterator([1, 2, 3]), 0).toArray();
   }).then(it => {
     assert.arrayEqual(it, [1, 2, 3], 'zero');
-    async();
   });
-
-  assert.throws(() => drop.call(undefined, 1), TypeError);
-  assert.throws(() => drop.call(null, 1), TypeError);
-  assert.throws(() => drop.call({}, 1), TypeError);
-  assert.throws(() => drop.call([], 1), TypeError);
-  assert.throws(() => drop.call(createIterator([1, 2, 3]), -1), RangeError, 'negative');
-  assert.throws(() => drop.call(createIterator([1, 2, 3]), NaN), RangeError, 'NaN');
 });
