@@ -1,9 +1,7 @@
-import { createIterator } from '../helpers/helpers';
-import { STRICT_THIS } from '../helpers/constants';
+import { createIterator } from '../helpers/helpers.js';
+import { STRICT, STRICT_THIS } from '../helpers/constants.js';
 
 QUnit.test('AsyncIterator#map', assert => {
-  assert.expect(18);
-  const async = assert.async();
   const { map } = AsyncIterator.prototype;
 
   assert.isFunction(map);
@@ -12,7 +10,16 @@ QUnit.test('AsyncIterator#map', assert => {
   assert.looksNative(map);
   assert.nonEnumerable(AsyncIterator.prototype, 'map');
 
-  map.call(createIterator([1, 2, 3]), it => it ** 2).toArray().then(it => {
+  if (STRICT) {
+    assert.throws(() => map.call(undefined, () => { /* empty */ }), TypeError);
+    assert.throws(() => map.call(null, () => { /* empty */ }), TypeError);
+  }
+
+  assert.throws(() => map.call(createIterator([1]), undefined), TypeError);
+  assert.throws(() => map.call(createIterator([1]), null), TypeError);
+  assert.throws(() => map.call(createIterator([1]), {}), TypeError);
+
+  return map.call(createIterator([1, 2, 3]), it => it ** 2).toArray().then(it => {
     assert.arrayEqual(it, [1, 4, 9], 'basic functionality');
     return map.call(createIterator([1]), function (arg, counter) {
       assert.same(this, STRICT_THIS, 'this');
@@ -22,15 +29,9 @@ QUnit.test('AsyncIterator#map', assert => {
     }).toArray();
   }).then(() => {
     return map.call(createIterator([1]), () => { throw 42; }).toArray();
-  }).catch(error => {
+  }).then(() => {
+    assert.avoid();
+  }, error => {
     assert.same(error, 42, 'rejection on a callback error');
-  }).then(() => async());
-
-  assert.throws(() => map.call(undefined, () => { /* empty */ }), TypeError);
-  assert.throws(() => map.call(null, () => { /* empty */ }), TypeError);
-  assert.throws(() => map.call({}, () => { /* empty */ }), TypeError);
-  assert.throws(() => map.call([], () => { /* empty */ }), TypeError);
-  assert.throws(() => map.call(createIterator([1]), undefined), TypeError);
-  assert.throws(() => map.call(createIterator([1]), null), TypeError);
-  assert.throws(() => map.call(createIterator([1]), {}), TypeError);
+  });
 });
