@@ -1,8 +1,7 @@
-import { createIterator } from '../helpers/helpers';
+import { STRICT } from '../helpers/constants.js';
+import { createIterator } from '../helpers/helpers.js';
 
 QUnit.test('AsyncIterator#take', assert => {
-  assert.expect(15);
-  const async = assert.async();
   const { take } = AsyncIterator.prototype;
 
   assert.isFunction(take);
@@ -11,7 +10,15 @@ QUnit.test('AsyncIterator#take', assert => {
   assert.looksNative(take);
   assert.nonEnumerable(AsyncIterator.prototype, 'take');
 
-  take.call(createIterator([1, 2, 3]), 2).toArray().then(it => {
+  if (STRICT) {
+    assert.throws(() => take.call(undefined, 1), TypeError);
+    assert.throws(() => take.call(null, 1), TypeError);
+  }
+
+  assert.throws(() => take.call(createIterator([1, 2, 3]), -1), RangeError, 'negative');
+  assert.throws(() => take.call(createIterator([1, 2, 3]), NaN), RangeError, 'NaN');
+
+  return take.call(createIterator([1, 2, 3]), 2).toArray().then(it => {
     assert.arrayEqual(it, [1, 2], 'basic functionality');
     return take.call(createIterator([1, 2, 3]), 1.5).toArray();
   }).then(it => {
@@ -22,13 +29,5 @@ QUnit.test('AsyncIterator#take', assert => {
     return take.call(createIterator([1, 2, 3]), 0).toArray();
   }).then(it => {
     assert.arrayEqual(it, [], 'zero');
-    async();
   });
-
-  assert.throws(() => take.call(undefined, 1), TypeError);
-  assert.throws(() => take.call(null, 1), TypeError);
-  assert.throws(() => take.call({}, 1), TypeError);
-  assert.throws(() => take.call([], 1), TypeError);
-  assert.throws(() => take.call(createIterator([1, 2, 3]), -1), RangeError, 'negative');
-  assert.throws(() => take.call(createIterator([1, 2, 3]), NaN), RangeError, 'NaN');
 });
