@@ -1,4 +1,5 @@
-import { createIterator } from '../helpers/helpers';
+import { STRICT } from '../helpers/constants.js';
+import { createIterator } from '../helpers/helpers.js';
 
 QUnit.test('Iterator#indexed', assert => {
   const { indexed } = Iterator.prototype;
@@ -11,8 +12,11 @@ QUnit.test('Iterator#indexed', assert => {
 
   assert.arrayEqual(indexed.call(createIterator(['a', 'b', 'c'])).toArray().toString(), '0,a,1,b,2,c', 'basic functionality');
 
-  assert.throws(() => indexed.call(undefined, TypeError));
-  assert.throws(() => indexed.call(null, TypeError));
-  assert.throws(() => indexed.call({}, TypeError));
-  assert.throws(() => indexed.call([], TypeError));
+  if (STRICT) {
+    assert.throws(() => indexed.call(undefined), TypeError);
+    assert.throws(() => indexed.call(null), TypeError);
+  }
+
+  assert.throws(() => indexed.call({}).next(), TypeError);
+  assert.throws(() => indexed.call([]).next(), TypeError);
 });
