@@ -1,9 +1,6 @@
-import { STRICT } from '../helpers/constants';
+import { STRICT } from '../helpers/constants.js';
 
 QUnit.test('Iterator#toAsync', assert => {
-  assert.expect(STRICT ? 9 : 7);
-  const async = assert.async();
-
   const { toAsync } = Iterator.prototype;
 
   assert.isFunction(toAsync);
@@ -17,11 +14,10 @@ QUnit.test('Iterator#toAsync', assert => {
     assert.throws(() => toAsync.call(null), TypeError);
   }
 
-  [1, 2, 3].values().toAsync().map(it => Promise.resolve(it)).toArray().then(it => {
+  return [1, 2, 3].values().toAsync().map(it => Promise.resolve(it)).toArray().then(it => {
     assert.arrayEqual(it, [1, 2, 3]);
     return new Set([1, 2, 3]).values().toAsync().map(el => Promise.resolve(el)).toArray();
   }).then(it => {
     assert.arrayEqual(it, [1, 2, 3]);
-    async();
   });
 });
