@@ -24,7 +24,7 @@ QUnit.test('Map#deleteAll', assert => {
   assert.true(set.deleteAll());
   assert.deepEqual(from(set), [[1, 2], [2, 3], [3, 4]]);
 
-  assert.notThrows(() => !deleteAll.call({ delete() { /* empty */ } }, 1, 2, 3));
+  assert.throws(() => deleteAll.call({ delete() { /* empty */ } }, 1, 2, 3));
   assert.throws(() => deleteAll.call({}, 1, 2, 3), TypeError);
   assert.throws(() => deleteAll.call(undefined, 1, 2, 3), TypeError);
   assert.throws(() => deleteAll.call(null, 1, 2, 3), TypeError);
