@@ -1,9 +1,12 @@
-import { timeLimitedPromise } from '../helpers/helpers';
+import { timeLimitedPromise } from '../helpers/helpers.js';
 
 QUnit.test('setInterval / clearInterval', assert => {
-  assert.expect(1);
+  assert.isFunction(setInterval, 'setInterval is function');
+  assert.isFunction(clearInterval, 'clearInterval is function');
+  assert.name(setInterval, 'setInterval');
+  assert.name(clearInterval, 'clearInterval');
 
-  timeLimitedPromise(1e4, (resolve, reject) => {
+  return timeLimitedPromise(1e4, (resolve, reject) => {
     let i = 0;
     const interval = setInterval((a, b) => {
       if (a + b !== 'ab' || i > 2) reject({ a, b, i });
@@ -14,8 +17,7 @@ QUnit.test('setInterval / clearInterval', assert => {
     }, 5, 'a', 'b');
   }).then(() => {
     assert.required('setInterval & clearInterval works with additional args');
-  }).catch(error => {
-    if (!error) error = {};
+  }, (error = {}) => {
     assert.avoid(`setInterval & clearInterval works with additional args: ${ error.a }, ${ error.b }, times: ${ error.i }`);
-  }).then(assert.async());
+  });
 });
