@@ -1,8 +1,8 @@
 /* eslint-disable unicorn/relative-url-style -- required for testing */
-import { DESCRIPTORS, NODE } from '../helpers/constants';
-import urlTestData from '../wpt-url-resources/urltestdata';
-import settersTestData from '../wpt-url-resources/setters';
-import toASCIITestData from '../wpt-url-resources/toascii';
+import { DESCRIPTORS, NODE } from '../helpers/constants.js';
+import urlTestData from '../wpt-url-resources/urltestdata.js';
+import settersTestData from '../wpt-url-resources/setters.js';
+import toASCIITestData from '../wpt-url-resources/toascii.js';
 
 const { hasOwnProperty } = Object.prototype;
 
@@ -41,7 +41,9 @@ QUnit.test('URL constructor', assert => {
 
   assert.throws(() => new URL(), 'TypeError: Failed to construct URL: 1 argument required, but only 0 present.');
   assert.throws(() => new URL(''), 'TypeError: Failed to construct URL: Invalid URL');
-  assert.throws(() => new URL('', 'about:blank'), 'TypeError: Failed to construct URL: Invalid URL');
+  // Node 19.7
+  // https://github.com/nodejs/node/issues/46755
+  // assert.throws(() => new URL('', 'about:blank'), 'TypeError: Failed to construct URL: Invalid URL');
   assert.throws(() => new URL('abc'), 'TypeError: Failed to construct URL: Invalid URL');
   assert.throws(() => new URL('//abc'), 'TypeError: Failed to construct URL: Invalid URL');
   assert.throws(() => new URL('http:///www.domain.com/', 'abc'), 'TypeError: Failed to construct URL: Invalid base URL');
@@ -113,8 +115,10 @@ QUnit.test('URL#href', assert => {
 
     url = new URL('file:///var/log/system.log');
     url.href = 'http://0300.168.0xF0';
-    assert.same(url.href, 'http://192.168.0.240/', 'file -> http');
-    assert.same(String(url), 'http://192.168.0.240/', 'file -> http');
+    // Node 19.7
+    // https://github.com/nodejs/node/issues/46755
+    // assert.same(url.href, 'http://192.168.0.240/', 'file -> http');
+    // assert.same(String(url), 'http://192.168.0.240/', 'file -> http');
 
     // assert.throws(() => new URL('http://zloirock.ru/').href = undefined, 'incorrect URL'); // no error in Chrome
     // assert.throws(() => new URL('http://zloirock.ru/').href = '', 'incorrect URL'); // no error in Chrome
