@@ -1,4 +1,4 @@
-import { createIterable } from '../helpers/helpers';
+import { createIterable } from '../helpers/helpers.js';
 
 import Set from 'core-js-pure/es/set';
 import fromEntries from 'core-js-pure/es/object/from-entries';
