@@ -1,4 +1,4 @@
-import { STRICT } from '../helpers/constants';
+import { STRICT } from '../helpers/constants.js';
 
 import Symbol from 'core-js-pure/es/symbol';
 import includes from 'core-js-pure/es/string/includes';
@@ -11,8 +11,9 @@ QUnit.test('String#includes', assert => {
   assert.false(includes('abcd', 'b', 2));
 
   if (!Symbol.sham) {
-    assert.throws(() => includes(Symbol(), 'b'), 'throws on symbol context');
-    assert.throws(() => includes('a', Symbol()), 'throws on symbol argument');
+    const symbol = Symbol('includes test');
+    assert.throws(() => includes(symbol, 'b'), 'throws on symbol context');
+    assert.throws(() => includes('a', symbol), 'throws on symbol argument');
   }
 
   if (STRICT) {
