@@ -9,11 +9,13 @@ QUnit.test('String.raw', assert => {
   assert.same(raw({ raw: ['Hi\\n', '!'] }, 'Bob'), 'Hi\\nBob!', 'raw is array');
   assert.same(raw({ raw: 'test' }, 0, 1, 2), 't0e1s2t', 'raw is string');
   assert.same(raw({ raw: 'test' }, 0), 't0est', 'lacks substituting');
+  assert.same(raw({ raw: [] }), '', 'empty template');
 
   /* eslint-disable es/no-symbol -- safe */
   if (typeof Symbol == 'function') {
-    assert.throws(() => raw({ raw: [Symbol()] }, 0), TypeError, 'throws on symbol #1');
-    assert.throws(() => raw({ raw: 'test' }, Symbol()), TypeError, 'throws on symbol #2');
+    const symbol = Symbol('raw test');
+    assert.throws(() => raw({ raw: [symbol] }, 0), TypeError, 'throws on symbol #1');
+    assert.throws(() => raw({ raw: 'test' }, symbol), TypeError, 'throws on symbol #2');
   }
 
   assert.throws(() => raw({}), TypeError);
