@@ -1,5 +1,5 @@
 import substr from 'core-js-pure/es/string/substr';
-import { STRICT } from '../helpers/constants';
+import { STRICT } from '../helpers/constants.js';
 
 QUnit.test('String#substr', assert => {
   assert.isFunction(substr);
@@ -10,7 +10,7 @@ QUnit.test('String#substr', assert => {
 
   /* eslint-disable es/no-symbol -- safe */
   if (typeof Symbol == 'function') {
-    assert.throws(() => substr(Symbol(), 1, 3), 'throws on symbol context');
+    assert.throws(() => substr(Symbol('substr test'), 1, 3), 'throws on symbol context');
   }
 
   if (STRICT) {
