@@ -1,6 +1,8 @@
+import { nativeSubclass } from '../helpers/helpers.js';
+
 import Symbol from 'core-js-pure/es/symbol';
 
-import AsyncIterator from 'core-js-pure/full/async-iterator';
+import AsyncIterator from 'core-js-pure/actual/async-iterator';
 
 QUnit.test('AsyncIterator', assert => {
   assert.isFunction(AsyncIterator);
@@ -9,7 +11,12 @@ QUnit.test('AsyncIterator', assert => {
   assert.true(AsyncIterator.from([1, 2, 3]) instanceof AsyncIterator, 'Async From Proxy');
   assert.true(AsyncIterator.from([1, 2, 3]).drop(1) instanceof AsyncIterator, 'Async Drop Proxy');
 
-  assert.true(new AsyncIterator() instanceof AsyncIterator, 'constructor');
+  if (nativeSubclass) {
+    const Sub = nativeSubclass(AsyncIterator);
+    assert.true(new Sub() instanceof AsyncIterator, 'abstract constructor');
+  }
+
+  assert.throws(() => new AsyncIterator(), 'direct constructor throws');
   assert.throws(() => AsyncIterator(), 'throws w/o `new`');
 });
 
