@@ -1,18 +1,25 @@
-import { createIterator } from '../helpers/helpers';
-import { STRICT_THIS } from '../helpers/constants';
+import { createIterator } from '../helpers/helpers.js';
+import { STRICT, STRICT_THIS } from '../helpers/constants.js';
 
-import AsyncIterator from 'core-js-pure/full/async-iterator';
+import AsyncIterator from 'core-js-pure/actual/async-iterator';
 
 QUnit.test('AsyncIterator#filter', assert => {
-  assert.expect(16);
-  const async = assert.async();
   const { filter } = AsyncIterator.prototype;
 
   assert.isFunction(filter);
   assert.arity(filter, 1);
   assert.nonEnumerable(AsyncIterator.prototype, 'filter');
 
-  filter.call(createIterator([1, 2, 3]), it => it % 2).toArray().then(it => {
+  if (STRICT) {
+    assert.throws(() => filter.call(undefined, () => { /* empty */ }), TypeError);
+    assert.throws(() => filter.call(null, () => { /* empty */ }), TypeError);
+  }
+
+  assert.throws(() => filter.call(createIterator([1]), undefined), TypeError);
+  assert.throws(() => filter.call(createIterator([1]), null), TypeError);
+  assert.throws(() => filter.call(createIterator([1]), {}), TypeError);
+
+  return filter.call(createIterator([1, 2, 3]), it => it % 2).toArray().then(it => {
     assert.arrayEqual(it, [1, 3], 'basic functionality');
     return filter.call(createIterator([1]), function (arg, counter) {
       assert.same(this, STRICT_THIS, 'this');
@@ -22,15 +29,9 @@ QUnit.test('AsyncIterator#filter', assert => {
     }).toArray();
   }).then(() => {
     return filter.call(createIterator([1]), () => { throw 42; }).toArray();
-  }).catch(error => {
+  }).then(() => {
+    assert.avoid();
+  }, error => {
     assert.same(error, 42, 'rejection on a callback error');
-  }).then(() => async());
-
-  assert.throws(() => filter.call(undefined, () => { /* empty */ }), TypeError);
-  assert.throws(() => filter.call(null, () => { /* empty */ }), TypeError);
-  assert.throws(() => filter.call({}, () => { /* empty */ }), TypeError);
-  assert.throws(() => filter.call([], () => { /* empty */ }), TypeError);
-  assert.throws(() => filter.call(createIterator([1]), undefined), TypeError);
-  assert.throws(() => filter.call(createIterator([1]), null), TypeError);
-  assert.throws(() => filter.call(createIterator([1]), {}), TypeError);
+  });
 });
