@@ -1,20 +1,27 @@
-import { createIterator } from '../helpers/helpers';
-import { STRICT_THIS } from '../helpers/constants';
+import { createIterator } from '../helpers/helpers.js';
+import { STRICT, STRICT_THIS } from '../helpers/constants.js';
 
-import AsyncIterator from 'core-js-pure/full/async-iterator';
+import AsyncIterator from 'core-js-pure/actual/async-iterator';
 
 QUnit.test('AsyncIterator#forEach', assert => {
-  assert.expect(16);
-  const async = assert.async();
   const { forEach } = AsyncIterator.prototype;
 
   assert.isFunction(forEach);
   assert.arity(forEach, 1);
   assert.nonEnumerable(AsyncIterator.prototype, 'forEach');
 
+  if (STRICT) {
+    assert.throws(() => forEach.call(undefined, () => { /* empty */ }), TypeError);
+    assert.throws(() => forEach.call(null, () => { /* empty */ }), TypeError);
+  }
+
+  assert.throws(() => forEach.call(createIterator([1]), undefined), TypeError);
+  assert.throws(() => forEach.call(createIterator([1]), null), TypeError);
+  assert.throws(() => forEach.call(createIterator([1]), {}), TypeError);
+
   const array = [];
 
-  forEach.call(createIterator([1, 2, 3]), it => array.push(it)).then(() => {
+  return forEach.call(createIterator([1, 2, 3]), it => array.push(it)).then(() => {
     assert.arrayEqual(array, [1, 2, 3], 'basic functionality');
     return forEach.call(createIterator([1]), function (arg, counter) {
       assert.same(this, STRICT_THIS, 'this');
@@ -24,15 +31,9 @@ QUnit.test('AsyncIterator#forEach', assert => {
     });
   }).then(() => {
     return forEach.call(createIterator([1]), () => { throw 42; });
-  }).catch(error => {
+  }).then(() => {
+    assert.avoid();
+  }, error => {
     assert.same(error, 42, 'rejection on a callback error');
-  }).then(() => async());
-
-  assert.throws(() => forEach.call(undefined, () => { /* empty */ }), TypeError);
-  assert.throws(() => forEach.call(null, () => { /* empty */ }), TypeError);
-  assert.throws(() => forEach.call({}, () => { /* empty */ }), TypeError);
-  assert.throws(() => forEach.call([], () => { /* empty */ }), TypeError);
-  assert.throws(() => forEach.call(createIterator([1]), undefined), TypeError);
-  assert.throws(() => forEach.call(createIterator([1]), null), TypeError);
-  assert.throws(() => forEach.call(createIterator([1]), {}), TypeError);
+  });
 });
