@@ -1,11 +1,10 @@
 import Promise from 'core-js-pure/es/promise';
 import assign from 'core-js-pure/es/object/assign';
+import create from 'core-js-pure/es/object/create';
 import values from 'core-js-pure/es/array/values';
-import AsyncIterator from 'core-js-pure/full/async-iterator';
+import AsyncIterator from 'core-js-pure/actual/async-iterator';
 
 QUnit.test('AsyncIterator.from', assert => {
-  assert.expect(10);
-  const async = assert.async();
   const { from } = AsyncIterator;
 
   assert.isFunction(from);
@@ -15,12 +14,7 @@ QUnit.test('AsyncIterator.from', assert => {
 
   assert.true(AsyncIterator.from([]) instanceof AsyncIterator, 'proxy, iterable');
 
-  AsyncIterator.from([1, Promise.resolve(2), 3]).toArray().then(result => {
-    assert.arrayEqual(result, [1, 2, 3], 'unwrap promises');
-    async();
-  });
-
-  const asyncIterator = assign(new AsyncIterator(), {
+  const asyncIterator = assign(create(AsyncIterator.prototype), {
     next: () => { /* empty */ },
   });
 
@@ -28,6 +22,8 @@ QUnit.test('AsyncIterator.from', assert => {
 
   assert.throws(() => from(undefined), TypeError);
   assert.throws(() => from(null), TypeError);
-  assert.throws(() => from({}), TypeError);
-  assert.throws(() => from(assign(new AsyncIterator(), { next: 42 })), TypeError);
+
+  return AsyncIterator.from([1, Promise.resolve(2), 3]).toArray().then(result => {
+    assert.arrayEqual(result, [1, 2, 3], 'unwrap promises');
+  });
 });
