@@ -1,6 +1,6 @@
-import { createIterable, createIterator } from '../helpers/helpers';
+import { createIterable, createIterator } from '../helpers/helpers.js';
 
-import Iterator from 'core-js-pure/full/iterator';
+import Iterator from 'core-js-pure/actual/iterator';
 import assign from 'core-js-pure/es/object/assign';
 
 QUnit.test('Iterator.from', assert => {
@@ -17,6 +17,6 @@ QUnit.test('Iterator.from', assert => {
 
   assert.throws(() => from(undefined), TypeError);
   assert.throws(() => from(null), TypeError);
-  assert.throws(() => from({}), TypeError);
-  assert.throws(() => from(assign(new Iterator(), { next: 42 })), TypeError);
+  assert.throws(() => from({}).next(), TypeError);
+  assert.throws(() => from(assign(new Iterator(), { next: 42 })).next(), TypeError);
 });
