@@ -1,6 +1,7 @@
-import { createIterator } from '../helpers/helpers';
+import { STRICT } from '../helpers/constants.js';
+import { createIterator } from '../helpers/helpers.js';
 
-import Iterator from 'core-js-pure/full/iterator';
+import Iterator from 'core-js-pure/actual/iterator';
 
 QUnit.test('Iterator#take', assert => {
   const { take } = Iterator.prototype;
@@ -14,10 +15,13 @@ QUnit.test('Iterator#take', assert => {
   assert.arrayEqual(take.call(createIterator([1, 2, 3]), 4).toArray(), [1, 2, 3], 'big');
   assert.arrayEqual(take.call(createIterator([1, 2, 3]), 0).toArray(), [], 'zero');
 
-  assert.throws(() => take.call(undefined, 1), TypeError);
-  assert.throws(() => take.call(null, 1), TypeError);
-  assert.throws(() => take.call({}, 1), TypeError);
-  assert.throws(() => take.call([], 1), TypeError);
+  if (STRICT) {
+    assert.throws(() => take.call(undefined, 1), TypeError);
+    assert.throws(() => take.call(null, 1), TypeError);
+  }
+
+  assert.throws(() => take.call({}, 1).next(), TypeError);
+  assert.throws(() => take.call([], 1).next(), TypeError);
   assert.throws(() => take.call(createIterator([1, 2, 3]), -1), RangeError, 'negative');
   assert.throws(() => take.call(createIterator([1, 2, 3]), NaN), RangeError, 'NaN');
 });
