@@ -1,4 +1,4 @@
-import { createIterable } from '../helpers/helpers';
+import { createIterable } from '../helpers/helpers.js';
 
 import toArray from 'core-js-pure/es/array/from';
 import Map from 'core-js-pure/full/map';
