@@ -7,21 +7,17 @@ QUnit.test('Promise.try', assert => {
 });
 
 QUnit.test('Promise.try, resolved', assert => {
-  assert.expect(1);
-  const async = assert.async();
-  Promise.try(() => 42).then(it => {
+  return Promise.try(() => 42).then(it => {
     assert.same(it, 42, 'resolved with a correct value');
-    async();
   });
 });
 
 QUnit.test('Promise.try, rejected', assert => {
-  assert.expect(1);
-  const async = assert.async();
-  Promise.try(() => {
+  return Promise.try(() => {
     throw new Error();
-  }).catch(() => {
+  }).then(() => {
+    assert.avoid();
+  }, () => {
     assert.true(true, 'rejected as expected');
-    async();
   });
 });
