@@ -1,4 +1,4 @@
-import { createIterable } from '../helpers/helpers';
+import { createIterable, createSetLike } from '../helpers/helpers.js';
 
 import Set from 'core-js-pure/full/set';
 
@@ -10,11 +10,20 @@ QUnit.test('Set#isSupersetOf', assert => {
   assert.name(isSupersetOf, 'isSupersetOf');
   assert.nonEnumerable(Set.prototype, 'isSupersetOf');
 
+  assert.true(new Set([1, 2, 3]).isSupersetOf(new Set([1])));
+  assert.false(new Set([2, 3, 4]).isSupersetOf(new Set([1])));
+  assert.true(new Set([5, 4, 3, 2, 1]).isSupersetOf(new Set([1, 2, 3])));
+  assert.false(new Set([5, 4, 3, 2]).isSupersetOf(new Set([1, 2, 3])));
+  assert.true(new Set([1, 2, 3]).isSupersetOf(createSetLike([1])));
+  assert.false(new Set([2, 3, 4]).isSupersetOf(createSetLike([1])));
+  assert.true(new Set([5, 4, 3, 2, 1]).isSupersetOf(createSetLike([1, 2, 3])));
+  assert.false(new Set([5, 4, 3, 2]).isSupersetOf(createSetLike([1, 2, 3])));
+
+  // TODO: drop from core-js@4
   assert.true(new Set([1, 2, 3]).isSupersetOf([1]));
   assert.false(new Set([2, 3, 4]).isSupersetOf([1]));
   assert.true(new Set([5, 4, 3, 2, 1]).isSupersetOf([1, 2, 3]));
   assert.false(new Set([5, 4, 3, 2]).isSupersetOf([1, 2, 3]));
-
   assert.true(new Set([1, 2, 3]).isSupersetOf(createIterable([1])));
   assert.false(new Set([2, 3, 4]).isSupersetOf(createIterable([1])));
 
