@@ -1,4 +1,4 @@
-import { createIterable } from '../helpers/helpers';
+import { createIterable } from '../helpers/helpers.js';
 
 import getIterator from 'core-js-pure/full/get-iterator';
 
@@ -6,6 +6,7 @@ QUnit.test('getIterator helper', assert => {
   assert.isFunction(getIterator);
   assert.isIterator(getIterator([]));
   assert.isIterator(getIterator(function () {
+    // eslint-disable-next-line prefer-rest-params -- required for testing
     return arguments;
   }()));
   assert.isIterator(getIterator(createIterable([])));
