@@ -1,23 +1,24 @@
-import { timeLimitedPromise } from '../helpers/helpers';
+import { timeLimitedPromise } from '../helpers/helpers.js';
 
 import setTimeout from 'core-js-pure/stable/set-timeout';
 
 QUnit.test('setTimeout / clearTimeout', assert => {
-  assert.expect(2);
+  assert.isFunction(setTimeout, 'setTimeout is function');
+  assert.isFunction(clearTimeout, 'clearTimeout is function');
 
-  timeLimitedPromise(1e3, resolve => {
+  return timeLimitedPromise(1e3, resolve => {
     setTimeout((a, b) => { resolve(a + b); }, 10, 'a', 'b');
   }).then(it => {
     assert.same(it, 'ab', 'setTimeout works with additional args');
-  }).catch(() => {
+  }, () => {
     assert.avoid('setTimeout works with additional args');
-  }).then(assert.async());
-
-  timeLimitedPromise(50, resolve => {
-    clearTimeout(setTimeout(resolve, 10));
+  }).then(() => {
+    return timeLimitedPromise(50, resolve => {
+      clearTimeout(setTimeout(resolve, 10));
+    });
   }).then(() => {
     assert.avoid('clearImmediate works with wrapped setTimeout');
-  }).catch(() => {
+  }, () => {
     assert.required('clearImmediate works with wrapped setTimeout');
-  }).then(assert.async());
+  });
 });
