@@ -1,5 +1,5 @@
-import { DESCRIPTORS } from '../helpers/constants';
-import { createIterable } from '../helpers/helpers';
+import { DESCRIPTORS } from '../helpers/constants.js';
+import { createIterable } from '../helpers/helpers.js';
 
 import getPrototypeOf from 'core-js-pure/es/object/get-prototype-of';
 import getOwnPropertyDescriptor from 'core-js-pure/es/object/get-own-property-descriptor';
@@ -107,7 +107,7 @@ QUnit.test('URLSearchParams', assert => {
     { input: { '+': '%C2' }, output: [['+', '%C2']], name: 'object with +' },
     { input: { c: 'x', a: '?' }, output: [['c', 'x'], ['a', '?']], name: 'object with two keys' },
     { input: [['c', 'x'], ['a', '?']], output: [['c', 'x'], ['a', '?']], name: 'array with two keys' },
-    // eslint-disable-next-line max-len -- ignore
+    // eslint-disable-next-line @stylistic/js/max-len -- ignore
     // !!! { input: { 'a\0b': '42', 'c\uD83D': '23', dሴ: 'foo' }, output: [['a\0b', '42'], ['c\uFFFD', '23'], ['d\u1234', 'foo']], name: 'object with NULL, non-ASCII, and surrogate keys' },
   ];
 
@@ -230,6 +230,18 @@ QUnit.test('URLSearchParams#delete', assert => {
   params.delete('first');
   assert.false(params.has('first'), 'search params object has no "first" name');
 
+  params = new URLSearchParams('a=1&a=2&a=null&a=3&b=4');
+  params.delete('a', 2);
+  assert.same(String(params), 'a=1&a=null&a=3&b=4');
+
+  params = new URLSearchParams('a=1&a=2&a=null&a=3&b=4');
+  params.delete('a', null);
+  assert.same(String(params), 'a=1&a=2&a=3&b=4');
+
+  params = new URLSearchParams('a=1&a=2&a=null&a=3&b=4');
+  params.delete('a', undefined);
+  assert.same(String(params), 'b=4');
+
   if (DESCRIPTORS) {
     let url = new URL('http://example.com/?param1&param2');
     url.searchParams.delete('param1');
@@ -373,6 +385,15 @@ QUnit.test('URLSearchParams#has', assert => {
   params.delete('first');
   assert.false(params.has('first'), 'search params object has no name "first"');
 
+  params = new URLSearchParams('a=1&a=2&a=null&a=3&b=4');
+  assert.true(params.has('a', 2));
+  assert.true(params.has('a', null));
+  assert.false(params.has('a', 4));
+  assert.true(params.has('b', 4));
+  assert.false(params.has('b', null));
+  assert.true(params.has('b', undefined));
+  assert.false(params.has('c', undefined));
+
   assert.throws(() => {
     return new URLSearchParams('').has();
   }, 'throws w/o arguments');
@@ -826,3 +847,20 @@ QUnit.test('URLSearchParams#@@iterator', assert => {
 
   if (DESCRIPTORS) assert.true(getOwnPropertyDescriptor(getPrototypeOf(new URLSearchParams()[Symbol.iterator]()), 'next').enumerable, 'enumerable .next');
 });
+
+QUnit.test('URLSearchParams#size', assert => {
+  const params = new URLSearchParams('a=1&b=2&b=3');
+  assert.true('size' in params);
+  assert.same(params.size, 3);
+
+  if (DESCRIPTORS) {
+    assert.true('size' in URLSearchParams.prototype);
+
+    const { enumerable, configurable, get } = getOwnPropertyDescriptor(URLSearchParams.prototype, 'size');
+
+    assert.true(enumerable, 'enumerable');
+    assert.true(configurable, 'configurable');
+
+    assert.throws(() => get.call([]));
+  }
+});
